jsTree v.1.0 - sort documentation

# jsTree v.1.0 - sort plugin

## Description

The `sort` enables jstree to automatically sort all nodes using a specified function. This means that when the user creates, renames or moves nodes around - they will automatically sort.

## Configuration

Expects a function. The functions receives two arguments - two nodes to be compared. Return `-1` or `1`. Default is:

`function (a, b) { return this.get_text(a) > this.get_text(b) ? 1 : -1; }`

## Demos

### Using the sort plugin

- Root node 1
  - Child node 1
  - Child node 2
- Root node 2

## API

### .sort ( node )

Sorts the children of the specified node - this function is called automatically.

- `mixed` node

  This can be a DOM node, jQuery node or selector pointing to the element.